import math

import pygame
from Mind import Imagination

from . import consts


def distance(x1, y1, x2, y2):
    return math.sqrt((x1 - x2) ** 2 + (y1 - y2) ** 2)


class Dark:
    def __init__(self, screen, l_size, percent):
        self.screen = screen
        self.size = screen.get_size()
        self.l_size = l_size
        self.percent = percent
        self.x = 0
        self.y = 0

        self.dark = pygame.Surface(self.size, pygame.SRCALPHA)
        self.dark.fill((0, 0, 0, self.percent))
        self.light = pygame.Surface((l_size, l_size), pygame.SRCALPHA)
        
        mult = 512 / l_size
        l_size2 = l_size / 2
        for y in range(l_size):
            for x in range(l_size):
                alpha = 255 - mult * distance(x, y, l_size2, l_size2)
                self.light.set_at((x, y), (0, 0, 0, max(alpha, 0)))

    def set_pos(self, x, y):
        self.x = int(x - self.l_size / 2)
        self.y = int(y - self.l_size / 2)

    def blit(self, light=True):
        self.dark.fill((0, 0, 0, self.percent))
        if light:
            self.dark.blit(self.light, (self.x, self.y),
                           special_flags=pygame.BLEND_RGBA_SUB)
        self.screen.blit(self.dark, (0, 0))


class EventDealer:
    def __init__(self):
        self.events = []

    def add(self, name, info=""):
        self.events.append((name, info))

    def get(self):
        return self.events

    def clear(self):
        self.events = []


class Scene:
    def __init__(self, game, places):
        self.printer = Imagination.printer(20, 20, consts.FONTS[1], 50,
                                           (255, 255, 255))
        with open(consts.join(consts.ART_PATH, "text.txt")) as file_:
            self.text = file_.read()
        print(self.text, file=self.printer)
        self.game = game
        self.places = [places[3]]
        self.next_place = places[1]
        self.keyboard = consts.KEYBOARD
        self.game.add_menu(self)

    def blit(self):
        self.printer.blit()

        self.keyboard.update()

        if self.keyboard["hit"] == 1:
            self.game.change(self.next_place)

        if self.keyboard["quit"] == 1:
            self.game.kill()

    def define(self, *args, **kwargs):
        pass
